@@ -70,7 +70,7 @@ class Recipe(GenericBaseRecipe):
     apache_conf['server_name'] = '%s' % apache_conf['ip']
     apache_conf['path'] = '/'
     apache_conf['access_control_string'] = access_control_string
-    apache_conf['rewrite_rule'] = "RewriteRule (.*) %s%s [L,P]" % (backend,
+    apache_conf['rewrite_rule'] = "RewriteRule (.*) %s%s$1 [L,P]" % (backend,
       self.options.get('backend-path', '/'))
     apache_conf_string = pkg_resources.resource_string(__name__,
           'template/apache.zope.conf.in') % apache_conf
